package com.thepattybeastlabs.ld35;

import java.awt.Color;
import java.io.File;
import java.lang.reflect.Field;

import com.thepattybeastlabs.core.AbstractCoreGame;
import com.thepattybeastlabs.core.Core;
import com.thepattybeastlabs.core.CoreFont;
import com.thepattybeastlabs.core.Graphics;
import com.thepattybeastlabs.core.audio.AudioEngine;
import com.thepattybeastlabs.core.console.Console;
import com.thepattybeastlabs.core.gui.Screen;
import com.thepattybeastlabs.core.gui.presetui.ConfigDialog;
import com.thepattybeastlabs.core.input.Input;
import com.thepattybeastlabs.core.resource.Image;

public class LD35 extends AbstractCoreGame {

	private Level level;
	
	public String getName() {
		return "LD35 Shapeshift";
	}
	
	public void init(Input in) throws Exception {
		Console.i().registerCommand("lvl", args->{
			try {
				level = new Level(new File("res/levels",args[0]));
			} catch (Exception e) {
				e.printStackTrace();
			}
		});
		CoreFont.list.load("Arial","Tahoma");
		//level = new Level(new File("res/levels/lvl_2.png"));
		Image.list.load("blank.bmp");
		in.createBind("Change Mode", "mode", Input.OS_MOUSE, "mwheel");
		in.createBind("Place", "place", Input.OS_MOUSE, "m1");
		in.createBind("Cancel Place", "cancel", Input.OS_MOUSE, "m2");
		in.createBind("Options", "options", Input.OS_KEYBOARD, "o");
		in.createBind("Exit", "exit", Input.OS_KEYBOARD, "escape");
	}

	public void render(Graphics g, Input in) throws Exception {
		if(level!=null){
			level.render(g);
			if(level.over()){
				g.setFont("Tahoma", 20);
				g.setTextAlign(1, 1);
				g.setColor(Color.WHITE);
				g.drawString("["+getBind("place",  in)+"] to restart", Core.width/2, Core.height-70, Color.BLACK);
				g.setTextAlign(0, 0);
			}
		}
		else{
			g.setFont("Tahoma", 20);
			g.setTextAlign(1, 1);
			g.setColor(Color.WHITE);
			g.drawString("Place - [" + getBind("place", in) + "] | Cancel Place - [" + getBind("cancel", in) + "] | Options - [" + getBind("options", in)
			+ "] | Exit - [" + getBind("exit", in)+"]", Core.width/2, Core.height-100);
			g.drawString("["+getBind("place",  in)+"] to start", Core.width/2, Core.height-70);
			g.drawString("A 1000% not broken game that works", Core.width/2, 230);
			g.drawString("Exactly as intended.", Core.width/2, 260);
			g.setTextAlign(1, 0);
			g.setFont("Tahoma", 60);
			g.drawString("Box Connector", Core.width/2, 100);
			g.setTextAlign(2, 2);
			g.setFont("Tahoma", 25);
			g.drawString("Created by thepattybeast in way less than 48 hours work.", Core.width, Core.height);
			g.setTextAlign(0, 0);
		}
	}
	
	private String getBind(String id, Input in){
		return in.getKeybind(id).getComponenet().getName();
	}

	public void tick(Input in, AudioEngine ae, float delta, Screen activeScreen) throws Exception {
		if(level!=null){
			if(level.over()){
				if(in.isPressed("place")){
					level = new Level(new File("res/levels/lvl_2.png"));
				}
			}
			level.tick(in,ae,delta);
		}
		else{
			if(in.isPressed("place")){
				level = new Level(new File("res/levels/lvl_2.png"));
			}
		}
		if(in.isPressed("options")){
			ConfigDialog.show("Core Engine Configuration");
		}
		if(in.isPressed("exit")){
			Core.exit();
		}
	}

	public static void main(String[] args) throws NoSuchFieldException, SecurityException, IllegalArgumentException, IllegalAccessException {
		Core.forceAr=false;
		Core.doDynamicResChanges=true;
		Core.showFPS=false;
		System.setProperty("java.library.path", "lib/native");
		Field pathField = ClassLoader.class.getDeclaredField("sys_paths");
		pathField.setAccessible(true);
		pathField.set(null, null);
		Core.targetFPS=0;
		Core.loadGame(args, 1280, 720, new LD35());
	}

}
