package com.thepattybeastlabs.ld35;

import java.awt.Color;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.swing.ActionMap;

import com.sun.javafx.image.impl.ByteIndexed.Getter;
import com.thepattybeastlabs.core.Core;
import com.thepattybeastlabs.core.Graphics;
import com.thepattybeastlabs.core.audio.AudioEngine;
import com.thepattybeastlabs.core.graphics.particles.ParticleSystem;
import com.thepattybeastlabs.core.input.Input;
import com.thepattybeastlabs.ld35.actionmode.ActionMode;
import com.thepattybeastlabs.ld35.actionmode.AttackActionMode;
import com.thepattybeastlabs.ld35.actionmode.PlaceActionMode;

public class Level {

	private Tile[][] tiles;
	
	private boolean currentPlayer=true, canPlace=true;
	public ActionMode[] modes = {new PlaceActionMode(),new AttackActionMode(),new UpgradeAction()};
	private LevelController player = new AILevelController();
	private LevelController ai = new PlayerLevelController();
	private boolean over = false;
	private ParticleSystem particles = new ParticleSystem();
	
	public Level(File path) throws IOException{
		BufferedImage image = ImageIO.read(path);
		tiles = new Tile[image.getWidth()][image.getHeight()];
		for(int x = 0; x < tiles.length; x++){
			for(int y = 0; y < tiles[0].length; y++){
				Color c = new Color(image.getRGB(x, y));
				if(c.getRed()==255||c.getBlue()==255){
					tiles[x][y] = new Tile(c.getRed()==255, c.getGreen());
				}
			}
		}
	}
	
	public void render(Graphics g){
		float tsize=Core.height/getHeight();
		float xOff=Core.width/2-(getWidth()*tsize)/2;
		for(int x = 0; x < tiles.length; x++){
			for(int y = 0; y < tiles[0].length; y++){
				if(tiles[x][y]!=null)tiles[x][y].render(g,x*tsize+xOff, y*tsize, tsize);
			}
		}
		g.setColor(Color.WHITE);
		for(int x = 0; x < tiles.length; x++){
			for(int y = 0; y < tiles[0].length; y++){
				g.setColor(Color.WHITE);
				g.drawRect(x*tsize+xOff, y*tsize, tsize, tsize);
			}
		}
		particles.render(g, xOff, 0);
		if(currentPlayer){
			player.render(this, g, xOff, 0, tsize);
		}else{
			ai.render(this, g, xOff, 0, tsize);
		}
		if(over){
			g.setFont("Tahoma", 100);
			g.setColor(Color.WHITE);
			g.setTextAlign(1, 1);
			g.drawString("You "+(currentPlayer?"Lose":"Win")+"!", Core.width/2, Core.height/2, Color.BLACK);
			g.setTextAlign(0, 0);
		}
		
	}
	
	public void tick(Input in, AudioEngine e, float delta){
		int tsize=Core.height/getHeight();
		float xOff=Core.width/2-(getWidth()*tsize)/2;
		if(!over){
			if(currentPlayer){
				player.tick(this, in, e, delta, xOff, 0, tsize);
			}else{
				ai.tick(this, in, e, delta, xOff, 0, tsize);
			}
		}
		for(int x = 0; x < tiles.length; x++){
			for(int y = 0; y < tiles[0].length; y++){
				if(tiles[x][y]!=null)tiles[x][y].tick(delta);
			}
		}
		particles.tick(delta, xOff, 0);
	}
	
	public int getWidth(){
		return tiles.length;
	}
	
	public int getHeight(){
		return tiles[0].length;
	}
	
	public boolean canPlace(){
		return canPlace;
	}
	
	public void endTurn(){
		boolean otherFound=false;
		for(int x = 0; x < tiles.length; x++){
			for(int y = 0; y < tiles[0].length; y++){
				if(tiles[x][y]!=null&&tiles[x][y].isPlayer()!=currentPlayer)otherFound=true;
			}
		}
		if(!otherFound)over=true;
		for(int x = 0; x < getWidth(); x++){
			if(isSide(x, getHeight()-1, false)){
				over=true;
				currentPlayer=true;return;
			}
		}
		for(int x = 0; x < getWidth(); x++){
			if(isSide(x, 0, true)){
				over=true;
				currentPlayer=false;return;
			}
		}
		if(currentPlayer==false)canPlace=!canPlace;
		currentPlayer=!currentPlayer;
		
	}
	
	public ActionMode[] modes(){
		return modes;
	}
	
	public Tile get(int x, int y){
		if(x>-1&&x<tiles.length&&y>-1&&y<tiles[0].length)return tiles[x][y];
		return null;
	}
	
	public boolean isSide(int x, int y, boolean side){
		Tile t = get(x,y);
		if(t==null)return false;
		return t.isPlayer()==side;
	}
	
	public void set(int x, int y, Tile tile){
		int tsize=Core.height/getHeight();
		if(get(x,y)!=null)particles.add(get(x,y).createEmitter(x*tsize, y*tsize, tsize));
		if(x>-1&&x<tiles.length&&y>-1&&y<tiles[0].length)tiles[x][y]=tile;
	}
	
	public boolean currentPlayer() {
		return currentPlayer;
	}

	public boolean over() {
		return over;
	}
	
}
