package com.thepattybeastlabs.ld35;

import java.awt.Color;

import com.thepattybeastlabs.core.Graphics;
import com.thepattybeastlabs.core.graphics.particles.DefaultParticleEmitter;
import com.thepattybeastlabs.core.graphics.particles.ParticleEmitter;
import com.thepattybeastlabs.core.utils.FixedValue;
import com.thepattybeastlabs.core.utils.RandomValue;

public class Tile {

	private boolean side;
	private int level;
	private float enterScale;
	
	public static final Color PLAYER=new Color(18,73,255), AI=new Color(255,89,18);
	
	/**Player=true*/
	public Tile(boolean side, int level) {
		this.side = side;
		this.level = level;
	}
	
	public void render(Graphics g, float x, float y, float ssize){
		float size=ssize*enterScale;
		x+=ssize/2-size/2;y+=ssize/2-size/2;
		g.setColor(side?PLAYER:AI);
		g.fillRect(x, y, size, size);
		g.setColor(Color.WHITE);
		if(level>0){
			g.setFont("Tahoma", size-2);
			g.setTextAlign(1, 1);
			g.drawString(level+"", x+(size/2),  y+(size/2));
			g.setTextAlign(0, 0);
		}
	}
	
	public ParticleEmitter createEmitter(float x, float y, float size){
		DefaultParticleEmitter p = new DefaultParticleEmitter();
		p.setX(new RandomValue(x, x+size));
		p.setY(new RandomValue(y, y+size));
		Color active = side?PLAYER:AI;
		p.setStartColor(new com.thepattybeastlabs.core.graphics.Color(active.getRed(),active.getGreen(),active.getBlue(),255));
		p.setEndColor(new com.thepattybeastlabs.core.graphics.Color(active.getRed(),active.getGreen(),active.getBlue(),0));
		p.setImage("blank.bmp");
		p.setSpawnAmount(new RandomValue(4, 6));
		p.setSpawnRate(new FixedValue(10000));
		p.setDespawn(true);
		p.setDespawnCountdown(100);
		p.setVelX(new RandomValue(-1, 1));
		p.setVelY(new RandomValue(-1, 1));
		p.setLife(new RandomValue(30, 60));
		return p;
	}
	
	public void tick(float delta){
		if(enterScale<1){
			enterScale+=0.03f*delta;
		}else{
			enterScale=1.0f;
		}
		
	}
	
	public int getRange(){
		return level/2+1;
	}
	
	public boolean isPlayer() {
		return side;
	}
	public void setPlayer(boolean side) {
		this.side = side;
	}
	public int getLevel() {
		return level;
	}
	public void setLevel(int level) {
		this.level = level;
	}
	
	
	
}
